package Refrigerator "Package containing models of household refrigerator in various scenarios"
  package Components "Package containing components for household refrigerator models"
    model ConvectionCooledFood "Food cooled by air"
      Modelica.Blocks.Sources.Constant heatTransfer(k = 12 * surfaceArea) annotation(Placement(visible = true, transformation(origin = {30.0, 30.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 180)));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor food(C = heatCapacity, T.start = initialTemperature) annotation(Placement(visible = true, transformation(origin = {30.0, -30.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b air annotation(Placement(visible = true, transformation(origin = {-80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-101.01, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      parameter Real surfaceArea = 1 "Food surface area for convection cooling";
      parameter Modelica.Units.SI.HeatCapacity heatCapacity = 10000 "Food heat capacity";
      parameter Modelica.Units.SI.Temperature initialTemperature = 273.15 "Initial temperature of food";
      Modelica.Thermal.HeatTransfer.Celsius.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {60.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Boolean frozenIcon = false;
    equation
      connect(convection.solid, temperatureSensor.port) annotation(Line(visible = true, origin = {30, 0}, points = {{-20, 0}, {20, 0}}, color = {191, 0, 0}));
      connect(heatTransfer.y, convection.Gc) annotation(Line(visible = true, origin = {6.333, 23.333}, points = {{12.667, 6.667}, {-6.333, 6.667}, {-6.333, -13.333}}, color = {1, 37, 163}));
      connect(convection.solid, food.port) annotation(Line(visible = true, origin = {23.333, -6.667}, points = {{-13.333, 6.667}, {6.667, 6.667}, {6.667, -13.333}}, color = {191, 0, 0}));
      connect(convection.fluid, air) annotation(Line(visible = true, origin = {-45, 0}, points = {{35, 0}, {-35, 0}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><div>
<div>This component models food cooled by air in the refrigerator or freezer compartment.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Bitmap(visible = not frozenIcon, fileName = "modelica://Refrigerator/DocumentationFiles/Food.png", imageSource = "", extent = {{-100, -100}, {100, 100}}), Text(visible = true, origin = {-3, -12}, textColor = {0, 0, 255}, extent = {{-117, -128}, {124, -88}}, textString = "%name", fontName = "Arial"), Bitmap(visible = frozenIcon, fileName = "modelica://Refrigerator/DocumentationFiles/FrozenFood.png", imageSource = "", extent = {{-100, -100}, {100, 100}})}), Diagram(coordinateSystem(extent = {{-80, -58.465}, {148.5, 70}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end ConvectionCooledFood;

    model OuterCase "Household refrigerator case and insulation"
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor freezerInsulation(G = 0.875 * 4 / 8) annotation(Placement(visible = true, transformation(origin = {1.5367, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor fridgeInsulation(G = 2.19 * 4 / 6) annotation(Placement(visible = true, transformation(origin = {1.5367, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection3 annotation(Placement(visible = true, transformation(origin = {40.0, -40.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 180)));
      Modelica.Blocks.Sources.Constant const3(k = 12) annotation(Placement(visible = true, transformation(origin = {0.0, 80.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 270)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection4 annotation(Placement(visible = true, transformation(origin = {40.0, 40.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = -180)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection6 annotation(Placement(visible = true, transformation(origin = {-40.0, 40.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 180)));
      Modelica.Blocks.Sources.Constant const6(k = 30) annotation(Placement(visible = true, transformation(origin = {-0.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
      Modelica.Thermal.HeatTransfer.Components.Convection convection7 annotation(Placement(visible = true, transformation(origin = {-40.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b freezerAir annotation(Placement(visible = true, transformation(origin = {150.0, 100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, 100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b fridgeAir annotation(Placement(visible = true, transformation(origin = {150.0, -100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, -100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b ambientAir annotation(Placement(visible = true, transformation(origin = {-150.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-102.1394, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(convection3.fluid, fridgeAir) annotation(Line(visible = true, origin = {115, -70}, points = {{-65, 30}, {15, 30}, {15, -30}, {35, -30}}, color = {191, 0, 0}));
      connect(convection4.fluid, freezerAir) annotation(Line(visible = true, origin = {115, 70}, points = {{-65, -30}, {15, -30}, {15, 30}, {35, 30}}, color = {191, 0, 0}));
      connect(convection6.fluid, ambientAir) annotation(Line(visible = true, origin = {-90, 20}, points = {{40, 20}, {10, 20}, {10, -20}, {-60, -20}}, color = {191, 0, 0}));
      connect(convection7.fluid, ambientAir) annotation(Line(visible = true, origin = {-90.419, -20}, points = {{40.419, -20}, {10.419, -20}, {10.419, 20}, {-59.581, 20}}, color = {191, 0, 0}));
      connect(convection4.Gc, const3.y) annotation(Line(visible = true, origin = {20, 62.75}, points = {{20, -12.75}, {20, 3.25}, {-20, 3.25}, {-20, 6.25}}, color = {0, 36, 164}));
      connect(convection6.Gc, const3.y) annotation(Line(visible = true, origin = {-20, 62.75}, points = {{-20, -12.75}, {-20, 3.25}, {20, 3.25}, {20, 6.25}}, color = {0, 36, 164}));
      connect(convection3.Gc, const6.y) annotation(Line(visible = true, origin = {20, -62.75}, points = {{20, 12.75}, {20, -3.25}, {-20, -3.25}, {-20, -6.25}}, color = {0, 36, 164}));
      connect(convection7.Gc, const6.y) annotation(Line(visible = true, origin = {-20, -62.75}, points = {{-20, 12.75}, {-20, -3.25}, {20, -3.25}, {20, -6.25}}, color = {0, 36, 164}));
      connect(fridgeInsulation.port_b, convection3.solid) annotation(Line(visible = true, origin = {20.768, -40}, points = {{-9.232, 0}, {9.232, 0}}, color = {191, 0, 0}));
      connect(fridgeInsulation.port_a, convection7.solid) annotation(Line(visible = true, origin = {-19.232, -40}, points = {{10.768, 0}, {-10.768, 0}}, color = {191, 0, 0}));
      connect(convection4.solid, freezerInsulation.port_b) annotation(Line(visible = true, origin = {20.768, 40}, points = {{9.232, 0}, {-9.232, 0}}, color = {191, 0, 0}));
      connect(freezerInsulation.port_a, convection6.solid) annotation(Line(visible = true, origin = {-19.232, 40}, points = {{10.768, 0}, {-10.768, 0}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><div>
<div>This component models the insulated case of the refrigerator and freezer compartments.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {255, 255, 255}, extent = {{-30.0, -60.0}, {30.0, 60.0}}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-46.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {114.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-6.0, 50.0}, points = {{36.0, -20.0}, {86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, 50.0}, points = {{56.0, -30.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, 50.0}, points = {{56.0, -10.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-6.0, -10.0}, points = {{36.0, -20.0}, {86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, -10.0}, points = {{56.0, -30.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {4.0, -10.0}, points = {{56.0, -10.0}, {76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {6.0, 50.0}, points = {{-36.0, -20.0}, {-86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, 50.0}, points = {{-56.0, -30.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, 50.0}, points = {{-56.0, -10.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {6.0, -10.0}, points = {{-36.0, -20.0}, {-86.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, -10.0}, points = {{-56.0, -30.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Line(visible = true, origin = {-4.0, -10.0}, points = {{-56.0, -10.0}, {-76.0, -20.0}}, color = {191, 0, 0}), Text(visible = true, origin = {-3.5, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial"), Line(visible = true, origin = {0.0, 10.0}, points = {{-30.0, 0.0}, {30.0, 0.0}}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {84.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, 60.0}, {-34.0, -80.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, -80.0}, {-44.0, -60.0}}, color = {0, 127, 255}), Line(visible = true, origin = {-16.0, 10.0}, points = {{-34.0, -80.0}, {-24.0, -60.0}}, color = {0, 127, 255})}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {0.0, 95.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "1 m^2 surface", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 25.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "8 cm polyfoam", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "6 cm polyfoam", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -95.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2.5 m^2 surface", fontSize = 12, fontName = "Arial")}));
    end OuterCase;

    model AirCirculation "Thermostat-controlled air circulation between compartments"
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow airCirculation(useVolumeFlowInput = true, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.01, T0 = 273.15, constantVolumeFlow = 1) annotation(Placement(visible = true, transformation(origin = {110.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Sources.AbsolutePressure pressure(p = 101325, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {80.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 90)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowPort_a1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FromKelvin celsius annotation(Placement(visible = true, transformation(origin = {-60.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Hysteresis thermostat(uHigh = 5, uLow = 2) annotation(Placement(visible = true, transformation(origin = {-20.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {70.0, 40.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 720)));
      Modelica.Blocks.Sources.Constant fanOff(k = 0) annotation(Placement(visible = true, transformation(origin = {20.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant fanOn(k = 0.003) annotation(Placement(visible = true, transformation(origin = {20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {-100.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a fridgeAir annotation(Placement(visible = true, transformation(origin = {0.0, 105.8333}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {0.0, 100.7937}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(celsius.Celsius, thermostat.u) annotation(Line(visible = true, origin = {-40.5, 40}, points = {{-8.5, 0}, {8.5, 0}}, color = {1, 37, 163}));
      connect(temperatureSensor.T, celsius.Kelvin) annotation(Line(visible = true, origin = {-81, 40}, points = {{-9, 0}, {9, 0}}, color = {1, 37, 163}));
      connect(switch.y, airCirculation.volumeFlow) annotation(Line(visible = true, origin = {100.333, 30}, points = {{-19.333, 10}, {9.667, 10}, {9.667, -20}}, color = {1, 37, 163}));
      connect(temperatureSensor.port, fridgeAir) annotation(Line(visible = true, origin = {-74, 73.167}, points = {{-36, -33.167}, {-56, -33.167}, {-56, 16.833}, {74, 16.833}, {74, 32.667}}, color = {191, 0, 0}));
      connect(thermostat.y, switch.u2) annotation(Line(visible = true, origin = {24.5, 40}, points = {{-33.5, 0}, {33.5, 0}}, color = {190, 52, 178}));
      connect(fanOff.y, switch.u3) annotation(Line(visible = true, origin = {42.25, 54}, points = {{-11.25, 6}, {-2.25, 6}, {-2.25, -6}, {15.75, -6}}, color = {1, 37, 163}));
      connect(fanOn.y, switch.u1) annotation(Line(visible = true, origin = {42.25, 26}, points = {{-11.25, -6}, {-2.25, -6}, {-2.25, 6}, {15.75, 6}}, color = {1, 37, 163}));
      connect(airCirculation.flowPort_b, flowPort_b1) annotation(Line(visible = true, origin = {135, 0}, points = {{-15, 0}, {15, 0}}, color = {190, 20, 31}));
      connect(airCirculation.flowPort_a, flowPort_a1) annotation(Line(visible = true, origin = {-25, 0}, points = {{125, 0}, {-125, 0}}, color = {190, 20, 31}));
      connect(airCirculation.flowPort_a, pressure.flowPort) annotation(Line(visible = true, origin = {86.667, -6.667}, points = {{13.333, 6.667}, {-6.667, 6.667}, {-6.667, -13.333}}, color = {190, 20, 31}));
      annotation(Documentation(info = "<html><div>
<div>This component models the thermostat-controlled air circulation between the refrigerator and freezer compartments.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, lineColor = {255, 0, 0}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-90.0, -90.0}, {90.0, 90.0}}), Polygon(visible = true, lineColor = {255, 0, 0}, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-60.0, 68.0}, {90.0, 10.0}, {90.0, -10.0}, {-60.0, -68.0}, {-60.0, 68.0}}), Text(visible = true, extent = {{-40.0, -20.0}, {0.0, 20.0}}, textString = "V", fontName = "Arial"), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -60}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end AirCirculation;

    model CompartmentDoor "Refrigerator or freezer compartment door"
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow circulationInDoor(useVolumeFlowInput = true, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.01, T0 = 293.15, constantVolumeFlow = 1) annotation(Placement(visible = true, transformation(origin = {40.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_a flowPort_a1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {-150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.FluidHeatFlow.Interfaces.FlowPort_b flowPort_b1(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {-30.0, 60.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 720)));
      Modelica.Blocks.Sources.Constant fanOff(k = 0) annotation(Placement(visible = true, transformation(origin = {-80.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant fanOn(k = airFlow) annotation(Placement(visible = true, transformation(origin = {-80.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.BooleanTable openCloseTable(table = schedule) annotation(Placement(visible = true, transformation(origin = {-120.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      parameter Modelica.Units.SI.Time schedule[:] = {1000, 1010} "Schedule of door open and close times";
      parameter Modelica.Units.SI.VolumeFlowRate airFlow = 0.001 "Air flow rate while door is open";
      Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), constantAmbientPressure = 101325, constantAmbientTemperature = 293.15) annotation(Placement(visible = true, transformation(origin = {-10.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
      Modelica.Thermal.FluidHeatFlow.Sources.VolumeFlow circulationOutDoor(m = 0.01, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), useVolumeFlowInput = true, T0 = 293.15, constantVolumeFlow = 1) annotation(Placement(visible = true, transformation(origin = {-30.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Thermal.FluidHeatFlow.Sources.Ambient ambient1(constantAmbientPressure = 101325, constantAmbientTemperature = 293.15, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC()) annotation(Placement(visible = true, transformation(origin = {20.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
    equation
      connect(ambient1.flowPort, circulationInDoor.flowPort_a) annotation(Line(visible = true, origin = {23.333, -10}, points = {{-3.333, -20}, {-3.333, 10}, {6.667, 10}}, color = {190, 20, 31}));
      connect(switch.y, circulationInDoor.volumeFlow) annotation(Line(visible = true, origin = {8.2, 34}, points = {{-27.2, 26}, {-8.2, 26}, {-8.2, -14}, {31.8, -14}, {31.8, -24}}, color = {1, 37, 163}));
      connect(circulationInDoor.flowPort_b, flowPort_b1) annotation(Line(visible = true, origin = {100, 0}, points = {{-50, 0}, {50, 0}}, color = {190, 20, 31}));
      connect(circulationOutDoor.flowPort_b, ambient.flowPort) annotation(Line(visible = true, origin = {-13.333, -10}, points = {{-6.667, 10}, {3.333, 10}, {3.333, -20}}, color = {190, 20, 31}));
      connect(switch.y, circulationOutDoor.volumeFlow) annotation(Line(visible = true, origin = {-15.8, 34}, points = {{-3.2, 26}, {15.8, 26}, {15.8, -14}, {-14.2, -14}, {-14.2, -24}}, color = {1, 37, 163}));
      connect(flowPort_a1, circulationOutDoor.flowPort_a) annotation(Line(visible = true, origin = {-95, 0}, points = {{-55, 0}, {55, 0}}, color = {190, 20, 31}));
      connect(openCloseTable.y, switch.u2) annotation(Line(visible = true, origin = {-75.5, 60}, points = {{-33.5, 0}, {33.5, 0}}, color = {190, 52, 178}));
      connect(fanOff.y, switch.u3) annotation(Line(visible = true, origin = {-57.75, 74}, points = {{-11.25, 6}, {-2.25, 6}, {-2.25, -6}, {15.75, -6}}, color = {1, 37, 163}));
      connect(fanOn.y, switch.u1) annotation(Line(visible = true, origin = {-57.75, 46}, points = {{-11.25, -6}, {-2.25, -6}, {-2.25, 6}, {15.75, 6}}, color = {1, 37, 163}));
      annotation(Documentation(info = "<html><div>
<div>This component models the air flow through the door of a refrigerator or freezer compartment.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {-20.0, 0.0}, lineColor = {255, 0, 0}, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-60.0, 68.0}, {90.0, 10.0}, {90.0, -10.0}, {-60.0, -68.0}, {-60.0, 68.0}}), Text(visible = true, extent = {{-40.0, -20.0}, {0.0, 20.0}}, textString = "V", fontName = "Arial"), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial"), Line(visible = true, origin = {80.0, 5.0}, points = {{0.0, 75.0}, {0.0, -75.0}}, color = {0, 0, 255}, thickness = 5)}), Diagram(coordinateSystem(extent = {{-148.5, -67.885}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {5.803, -55}, extent = {{-20, -5}, {20, 5}}, textString = "20 C", fontSize = 12, fontName = "Arial")}));
    end CompartmentDoor;

    model Cooling "Thermostat-controlled cooling"
      Modelica.Thermal.HeatTransfer.Components.Convection convection annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = -540)));
      Modelica.Blocks.Sources.Constant heatTransfer(k = 6) annotation(Placement(visible = true, transformation(origin = {-100.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_b freezerAir annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {101.0101, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Constant noHeatTransfer(k = 0) annotation(Placement(visible = true, transformation(origin = {-100.0, 60.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      Modelica.Blocks.Logical.Switch switch annotation(Placement(visible = true, transformation(origin = {-40.0, 30.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 360)));
      Modelica.Blocks.Logical.Hysteresis thermostat(uHigh = -14, uLow = -18.5, pre_y_start = false) annotation(Placement(visible = true, transformation(origin = {-40.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperatureSensor annotation(Placement(visible = true, transformation(origin = {40.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FromKelvin celcius annotation(Placement(visible = true, transformation(origin = {0.0, 80.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature r134a(T = -26.5) annotation(Placement(visible = true, transformation(origin = {0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(r134a.port, convection.solid) annotation(Line(visible = true, origin = {20, 0}, points = {{-10, 0}, {10, 0}}, color = {191, 0, 0}));
      connect(noHeatTransfer.y, switch.u3) annotation(Line(visible = true, origin = {-75.25, 49}, points = {{-13.75, 11}, {-4.75, 11}, {-4.75, -11}, {23.25, -11}}, color = {1, 37, 163}));
      connect(heatTransfer.y, switch.u1) annotation(Line(visible = true, origin = {-77.75, 16}, points = {{-11.25, -16}, {-2.25, -16}, {-2.25, 6}, {25.75, 6}}, color = {1, 37, 163}));
      connect(freezerAir, temperatureSensor.port) annotation(Line(visible = true, origin = {75, 60}, points = {{75, -60}, {45, -60}, {45, 20}, {-25, 20}}, color = {191, 0, 0}));
      connect(temperatureSensor.T, celcius.Kelvin) annotation(Line(visible = true, origin = {21, 80}, points = {{9, 0}, {-9, 0}}, color = {1, 37, 163}));
      connect(celcius.Celsius, thermostat.u) annotation(Line(visible = true, origin = {-19.5, 80}, points = {{8.5, 0}, {-8.5, 0}}, color = {1, 37, 163}));
      connect(thermostat.y, switch.u2) annotation(Line(visible = true, origin = {-95.75, 40}, points = {{44.75, 40}, {-34.25, 40}, {-34.25, -10}, {43.75, -10}}, color = {190, 52, 178}));
      connect(switch.y, convection.Gc) annotation(Line(visible = true, origin = {17, 23.333}, points = {{-46, 6.667}, {23, 6.667}, {23, -13.333}}, color = {1, 37, 163}));
      connect(convection.fluid, freezerAir) annotation(Line(visible = true, origin = {115, -20}, points = {{-65, 20}, {5, 20}, {5, 20}, {35, 20}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<html><div>
<div>This component models the thermostat-controlled cooling of the freezer compartment.</div>
</div></html>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {10.0, 60.0}, rotation = -270, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, points = {{-10.0, -10.0}, {0.0, 20.0}, {10.0, -10.0}}), Polygon(visible = true, origin = {-0.0, -60.0}, rotation = -450, fillColor = {0, 0, 255}, fillPattern = FillPattern.Solid, points = {{-10.0, -10.0}, {0.0, 20.0}, {10.0, -10.0}}), Line(visible = true, origin = {-40.0, 0.0}, points = {{30.0, 60.0}, {-30.0, 60.0}, {-30.0, -60.0}, {30.0, -60.0}}), Line(visible = true, origin = {45.0, 0.0}, points = {{-25.0, -60.0}, {25.0, -60.0}, {25.0, 60.0}, {-25.0, 60.0}}), Line(visible = true, origin = {85.0, 0.0}, points = {{-15.0, 0.0}, {15.0, 0.0}}), Text(visible = true, origin = {-3.0, 18.0}, lineColor = {0, 0, 255}, extent = {{-117.0, -128.0}, {124.0, -88.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -43.524}, {148.5, 105}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {-100, -20}, extent = {{-20, -5}, {20, 5}}, textString = "0.12 m^2 fan forced", fontSize = 12, fontName = "Arial")}));
    end Cooling;
    annotation(Documentation(info = "<html></html>"), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {191, 191, 191}, fillColor = {255, 255, 255}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90.0, -90.0}, {90.0, 90.0}}, radius = 25)}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
  end Components;

  model DoorOpening "Model simulating effect of opening and closing compartment doors on a refrigerator"
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = 33400, initialTemperature = 257.15, surfaceArea = 1, frozenIcon = true) annotation(Placement(visible = true, transformation(origin = {120, 70}, extent = {{10, 10}, {-10, -10}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = 78800, initialTemperature = 277.15, surfaceArea = 2) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120, -0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15, h_g = 0, V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), h_g = 0, V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = freezerSchedule, airFlow = freezerAirFlow) annotation(Placement(visible = true, transformation(origin = {0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = fridgeAirFlow, schedule = fridgeSchedule) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    parameter Modelica.Units.SI.Time freezerSchedule[:] = {690, 720, 1890, 1920, 3090, 3120, 15090, 15120, 16290, 16320, 17490, 17520, 36690, 36720, 37890, 37920, 39090, 39120, 47490, 47520, 48690, 48720, 49890, 49920} "Schedule of freezer door open and close times";
    parameter Modelica.Units.SI.VolumeFlowRate freezerAirFlow = 0.05 "Air flow rate while freezer door is open";
    parameter Modelica.Units.SI.Time fridgeSchedule[:] = {600, 620, 1200, 1220, 1800, 1820, 2400, 2420, 3000, 3020, 3600, 3620, 15000, 15020, 15600, 15620, 16200, 16220, 16800, 16820, 17400, 17420, 18000, 18020, 36600, 36620, 37200, 37220, 37800, 37820, 38400, 38420, 39000, 39020, 39600, 39620, 47400, 47420, 48000, 48020, 48600, 48620, 49200, 49220, 49800, 49820, 50400, 50420} "Schedule of fridge door open and close times";
    parameter Modelica.Units.SI.VolumeFlowRate fridgeAirFlow = 0.1 "Air flow rate while fridge door is open";
  equation
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, -0}, points = {{-9.893, -0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(preferredView = "info", experiment(StartTime = 0.0, StopTime = 8000, __Wolfram_Algorithm = "cvodes", __Wolfram_SynchronizeWithRealTime = false), __Wolfram(ControlPanels(Panel(identifier = "magical-fibonacci", title = "Model Parameters", elements = {InputField(variable = freezerAirFlow, label = "Air flow rate while freezer door is open"), InputField(variable = fridgeAirFlow, label = "Air flow rate while fridge door is open")}))), Documentation(info = "<html>
<p>This model simulates the effect of opening and closing the refrigerator and freezer compartment doors in a household refrigerator. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.</p>

<p>The other two models in this example are <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> and <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a>, which compare the effects of adding hot food to a normally loaded and a near-empty refrigerator, respectively.</p>

<h4>Simulation</h4>

<p>The model simulates the effect of opening and closing compartment doors according to a prespecified schedule. To see or modify the schedule, select the fridgeDoor or freezerDoor components in the <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a> model. The schedule is specified in the Parameters view at the bottom of Model Center.</p>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Refrigerator/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"simulate\" /></p>

<p>By default, the model is simulated over a period of 8000 seconds.</p>

<h4>Visualization</h4>

<p>After simulating the model, a Model plot will be displayed, showing the temperature of the air and food in the freezer compartment. An annotated version of the freezer compartment plot looks like this</p>

<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/freezerCompartmentDoorOpening.png\" style=\"width:600px\" alt=\"freezerCompartmentDoorOpening\" /></p>

<p>You can see that there are several discontinuities in the rate of temperature change corresponding to predetermined events such as compartment doors opening and closing, and dynamic events such as thermostats being triggered.</p>

<h3>Visualize Events</h3>

<p>You can visualize the various discrete events by clicking on the Model plot name Events</p>

<p>The resulting plot looks like this, depending on your choice of styles:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/discreteEvents.png\" style=\"width:600px\" alt=\"\" /></p>

<h4>Other Scenarios</h4>

<p>Try simulating the other two models in this example, <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> and <a href=\"modelica://Refrigerator.HotFood\">NearEmpty</a>, to compare the effects of adding hot food to a normally loaded and near-empty refrigerator, respectively.</p>
</html>", figures = {Figure(title = "Freezer door opening", identifier = "a69bd", plots = {Plot(curves = {Curve(y = frozenFood.air.T, legend = "Freezer Air Temperature"), Curve(y = frozenFood.food.T, legend = "Freezer Food Temperature")}, x = Axis(unit = "min")), Plot(curves = {Curve(y = freezerDoor.openCloseTable.y, legend = "Freezer Door Open")}, x = Axis(min = 0, max = 133.3333333333333, unit = "min"))}), Figure(title = "Fridge temperature", identifier = "fb433", plots = {Plot(curves = {Curve(y = freshFood.air.T, legend = "Fridge Air Temperature"), Curve(y = freshFood.food.T, legend = "Fridge Food Temperature")}, x = Axis(unit = "min"))}), Figure(title = "Fridge door opening", identifier = "d8d42", preferred = true, plots = {Plot(curves = {Curve(y = freshFood.air.T, legend = "Fridge Air Temperature"), Curve(y = freshFood.food.T, legend = "Fridge Food Temperature")}, x = Axis(unit = "min")), Plot(curves = {Curve(y = fridgeDoor.openCloseTable.y, legend = "Fridge Door Open")}, x = Axis(min = 0, max = 133.3333333333333, unit = "min"))}), Figure(title = "Freezer temperature", identifier = "91a71", plots = {Plot(curves = {Curve(y = frozenFood.air.T, legend = "Freezer Air Temperature"), Curve(y = frozenFood.food.T, legend = "Freezer Food Temperature")}, x = Axis(unit = "min"))}), Figure(title = "Events", identifier = "47e35", plots = {Plot(curves = {Curve(y = airCirculation.switch.u2, legend = "Thermostat control")}, x = Axis(unit = "min"), y = Axis(label = "On/Off")), Plot(curves = {Curve(y = freezerDoor.switch.u2, legend = "Freezer door")}, x = Axis(unit = "min"), y = Axis(label = "Open/Closed")), Plot(curves = {Curve(y = fridgeDoor.switch.u2, legend = "Fridge door")}, x = Axis(unit = "min"), y = Axis(label = "Open/Closed")), Plot(curves = {Curve(y = heatPump.switch.u2, legend = "Heat pump")}, x = Axis(unit = "min"), y = Axis(label = "On/Off"))})}), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial")}));
  end DoorOpening;

  model HotFood "Model simulating the effect of adding hot food to refrigerator"
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = 33400, initialTemperature = initialTemperatureFrozenFood, surfaceArea = 1, frozenIcon = true, food.T.fixed = true) annotation(Placement(visible = true, transformation(origin = {120.0, 70.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = 78800, initialTemperature = initialTemperatureFreshFood, surfaceArea = 2, food.T.fixed = true) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15, h_g = 0, V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), h_g = 0, V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = {999999, 9999999}, airFlow = 0.05) annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = 0.1, schedule = {999999, 9999999}) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood hotFood(heatCapacity = 7880, initialTemperature = initialTemperatureHotFood, surfaceArea = 0.4, food.T.fixed = true) annotation(Placement(visible = true, transformation(origin = {90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
    parameter Modelica.Units.SI.Temperature initialTemperatureFrozenFood = 257.15 "Initial temperature of frozen food";
    parameter Modelica.Units.SI.Temperature initialTemperatureHotFood = 323.15 "Initial temperature of hot food";
    parameter Modelica.Units.SI.Temperature initialTemperatureFreshFood = 277.15 "Initial temperature of fresh food";
  equation
    connect(hotFood.air, fridgeCompartment.heatPort) annotation(Line(visible = true, origin = {40, -85.025}, points = {{50, 44.924}, {50, -4.975}, {-40, -4.975}, {-40, 5.025}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, 0}, points = {{-9.893, 0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(preferredView = "info", experiment(StartTime = 0.0, StopTime = 7200, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(ControlPanels(Panel(identifier = "recursing-poincare", title = "Model Parameters", elements = {InputField(variable = initialTemperatureFreshFood, label = "Initial temperature of fresh food"), InputField(variable = initialTemperatureFrozenFood, label = "Initial temperature of frozen food"), InputField(variable = initialTemperatureHotFood, label = "Initial temperature of hot food")}))), Documentation(info = "<html>
<p>This model simulates the effect of adding hot food to a household refrigerator. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.</p>

<p>This model should be compared with the <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a> model, which simulates the addition of hot food to a near-empty refrigerator.</p>

<p>The other model in this example is <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, which simulates the effects of opening and closing the compartment doors.</p>

<h4>Simulation</h4>

<p>The model simulates the effect of a piece of hot food added at <em>t</em>=0 seconds to a refrigerator already normally loaded with both fresh and frozen food.</p>

<p>To simulate the model, click the Simulate button: <img src=\"modelica://Refrigerator/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"simulate\" /></p>

<p>By default, the model is simulated over a period of 7200 seconds.</p>

<h4>Visualization</h4>

<p>After simulating the model, look at the displayed plot of the food and air temperatures in the refrigerator compartment. The plot looks like this:</p>


<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/hotFoodTemperatures.png\" style=\"width:600px\" alt=\"\" /></p>
<p>You can see that the fresh food temperature increases by about 2 K, which is within acceptable limits.</p>

<p>By simulating the <a href=\"modelica://Refrigerator.NearEmpty\">NearEmpty</a> model, you can see the effect of adding hot food to a near-empty refrigerator instead of a normally loaded one:</p>


<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/nearEmptyTemperatures.png\" style=\"width:600px\" alt=\"\" /></p>

<p>You can see that, in the near-empty refrigerator, the fresh food temperature increases by about 7 K, outside acceptable limits. The low thermal mass of the near-empty refrigerator also leads to excessively frequent thermostat switching, visible after <em>t</em>=5500 seconds.</p>

<h4>Other Scenario</h4>

<p>Try simulating the other model in this example, <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, to explore the effects of opening and closing the refrigerator and freezer compartment doors.</p>
</html>", figures = {Figure(title = "Food temperature", identifier = "e067c", preferred = true, plots = {Plot(curves = {Curve(y = hotFood.temperatureSensor.T, legend = "Hot Food"), Curve(y = freshFood.temperatureSensor.T, legend = "Fresh Food"), Curve(y = frozenFood.food.T, legend = "Frozen Food")}, x = Axis(unit = "min"))}), Figure(title = "Comparment temperatures", identifier = "4bade", plots = {Plot(curves = {Curve(y = fridgeCompartment.T, legend = "Temperature of fridge compartment"), Curve(y = freezerCompartment.T, legend = "Temperature of freezer compartment")}, x = Axis(unit = "min"))}), Figure(title = "Events", identifier = "9341e", plots = {Plot(curves = {Curve(y = heatPump.switch.u2, legend = "Heat Pump")}, x = Axis(unit = "min"), y = Axis(label = "On/Off")), Plot(curves = {Curve(y = airCirculation.switch.u2, legend = "Thermostat")}, x = Axis(min = 0, max = 133.3333333333333, unit = "min"), y = Axis(label = "On/Off"))})}), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "20 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {90.0, -15.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of hot asparagus", fontSize = 12, fontName = "Arial")}));
  end HotFood;

  model NearEmpty "Model simulating the effect of adding hot food to nearly-empty refrigerator"
    extends Modelica.Icons.Example;
    Refrigerator.Components.OuterCase outerCase annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood frozenFood(heatCapacity = heatCapacityFrozenFood, initialTemperature = 257.15, surfaceArea = 0.1, frozenIcon = true) annotation(Placement(visible = true, transformation(origin = {120.0, 70.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 90)));
    Refrigerator.Components.ConvectionCooledFood freshFood(heatCapacity = heatCapacityFreshFood, initialTemperature = 277.15, surfaceArea = 0.2) annotation(Placement(visible = true, transformation(origin = {120.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    Refrigerator.Components.Cooling heatPump annotation(Placement(visible = true, transformation(origin = {70.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -630)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambient(T = 20) annotation(Placement(visible = true, transformation(origin = {-120.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe freezerCompartment(medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), m = 0.2, T0 = 257.15, h_g = 0, V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
    Modelica.Thermal.FluidHeatFlow.Components.Pipe fridgeCompartment(T0 = 277.15, m = 0.4, medium = Modelica.Thermal.FluidHeatFlow.Media.Air_30degC(), V_flowLaminar = 0.1, dpLaminar = 0, V_flowNominal = 1, dpNominal = 0, h_g = 0, useHeatPort = true) annotation(Placement(visible = true, transformation(origin = {0.0, -70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.AirCirculation airCirculation annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 270)));
    Refrigerator.Components.CompartmentDoor freezerDoor(schedule = {999999, 9999999}, airFlow = 0.05) annotation(Placement(visible = true, transformation(origin = {0.0, 30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.CompartmentDoor fridgeDoor(airFlow = 0.1, schedule = {999999, 9999999}) annotation(Placement(visible = true, transformation(origin = {0.0, -30.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    Refrigerator.Components.ConvectionCooledFood hotFood(heatCapacity = heatCapacityHotFood, initialTemperature = 323.15, surfaceArea = 0.4) annotation(Placement(visible = true, transformation(origin = {90.0, -30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    parameter Modelica.Units.SI.HeatCapacity heatCapacityFrozenFood = 3340 "Frozen food heat capacity";
    parameter Modelica.Units.SI.HeatCapacity heatCapacityHotFood = 7880 "Frozen food heat capacity";
    parameter Modelica.Units.SI.HeatCapacity heatCapacityFreshFood = 7880 "Fresh food heat capacity";
  equation
    connect(hotFood.air, fridgeCompartment.heatPort) annotation(Line(visible = true, origin = {40, -85.025}, points = {{50, 44.924}, {50, -4.975}, {-40, -4.975}, {-40, 5.025}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, freshFood.air) annotation(Line(visible = true, origin = {55, -85.025}, points = {{-55, 5.025}, {-55, -4.975}, {65, -4.975}, {65, 4.924}}, color = {191, 0, 0}));
    connect(fridgeCompartment.heatPort, outerCase.fridgeAir) annotation(Line(visible = true, origin = {-47.98, -53.905}, points = {{47.98, -26.095}, {47.98, -36.095}, {-12.02, -36.095}, {-22.02, -36.095}, {-22.02, 43.905}}, color = {191, 0, 0}));
    connect(freezerCompartment.heatPort, outerCase.freezerAir) annotation(Line(visible = true, origin = {-47.98, 53.905}, points = {{47.98, 26.095}, {47.98, 36.095}, {-12.02, 36.095}, {-22.02, 36.095}, {-22.02, -43.905}}, color = {191, 0, 0}));
    connect(ambient.port, outerCase.ambientAir) annotation(Line(visible = true, origin = {-100.107, 0}, points = {{-9.893, 0}, {9.893, 0}}, color = {191, 0, 0}));
    connect(fridgeDoor.flowPort_b1, fridgeCompartment.flowPort_a) annotation(Line(visible = true, origin = {-25.025, -50}, points = {{14.924, 20}, {-14.975, 20}, {-14.975, -20}, {15.025, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, fridgeDoor.flowPort_a1) annotation(Line(visible = true, origin = {25.025, -50}, points = {{-15.025, -20}, {14.975, -20}, {14.975, 20}, {-14.924, 20}}, color = {190, 20, 31}));
    connect(freezerDoor.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {25.025, 50}, points = {{-14.924, -20}, {14.975, -20}, {14.975, 20}, {-15.025, 20}}, color = {190, 20, 31}));
    connect(freezerCompartment.flowPort_b, freezerDoor.flowPort_a1) annotation(Line(visible = true, origin = {-25.025, 50}, points = {{15.025, 20}, {-14.975, 20}, {-14.975, -20}, {14.924, -20}}, color = {190, 20, 31}));
    connect(fridgeCompartment.heatPort, airCirculation.fridgeAir) annotation(Line(visible = true, origin = {38.016, -55.2}, points = {{-38.016, -24.8}, {-38.016, -34.8}, {21.984, -34.8}, {21.984, 55.2}, {12.063, 55.2}}, color = {191, 0, 0}));
    connect(fridgeCompartment.flowPort_a, freezerCompartment.flowPort_b) annotation(Line(visible = true, origin = {-25, 0}, points = {{15, -70}, {-15, -70}, {-15, 70}, {15, 70}}, color = {190, 20, 31}));
    connect(heatPump.freezerAir, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {30, 87.55}, points = {{40, -7.449}, {40, 2.55}, {-30, 2.45}, {-30, -7.55}}, color = {191, 0, 0}));
    connect(frozenFood.air, freezerCompartment.heatPort) annotation(Line(visible = true, origin = {55, 87.55}, points = {{65, -7.449}, {65, 2.55}, {-55, 2.45}, {-55, -7.55}}, color = {191, 0, 0}));
    connect(airCirculation.flowPort_b1, freezerCompartment.flowPort_a) annotation(Line(visible = true, origin = {30, 50.034}, points = {{10, -39.933}, {10, 19.966}, {-20, 19.966}}, color = {190, 20, 31}));
    connect(fridgeCompartment.flowPort_b, airCirculation.flowPort_a1) annotation(Line(visible = true, origin = {30, -50.034}, points = {{-20, -19.966}, {10, -19.966}, {10, 39.933}}, color = {190, 20, 31}));
    annotation(preferredView = "info", experiment(StartTime = 0.0, StopTime = 7200, Tolerance = 1e-07, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(ControlPanels(Panel(identifier = "great-ramanujan", title = "Model Parameters", elements = {InputField(variable = heatCapacityFreshFood, label = "Fresh food heat capacity"), InputField(variable = heatCapacityFrozenFood, label = "Frozen food heat capacity"), InputField(variable = heatCapacityHotFood, label = "Hot food heat capacity")}))), Documentation(info = "<html><div>
<div>This model simulates the effect of adding hot food to a household refrigerator that is nearly empty. The flow of heat and the circulation of air, both within the refrigerator and between the refrigerator and the external environment, are modeled with components from the <a href=\"modelica://Modelica.Thermal.HeatTransfer\">HeatTransfer</a> library and the <a href=\"modelica://Modelica.Thermal.FluidHeatFlow\">FluidHeatFlow</a> library.</div>
</div>
<div>
<div class=\"contenttable\">
<p>This model should be compared with the <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> model, which simulates the addition of hot food to a normally loaded refrigerator.</p>
<p>The other model in this example is <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, which simulates the effects of opening and closing the compartment doors.</p>
<h4>Simulation</h4>
<p>The model simulates the effect of a piece of hot food added at <em>t</em>=0 seconds to a refrigerator that is nearly empty, with only a small amount of fresh and frozen food stored in the compartments.</p>
<p>To simulate the model, click the Simulate button: <img src=\"modelica://Refrigerator/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"simulate\" /></p>
<p>By default, the model is simulated over a period of 7200 seconds.</p>
<h4>Visualization</h4>
<p>After simulating the model, look at the displayed plot of the food and air temperatures in the refrigerator compartment. The plot looks like this:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/nearEmptyTemperatures.png\" style=\"width:600px\" alt=\"\" /></p>
<p>You can see that the fresh food temperature increases by about 7 K, outside acceptable limits. The low thermal mass of the near-empty refrigerator also leads to excessively frequent thermostat switching, visible after <em>t</em>=5500 seconds.</p>
<p>By simulating the <a href=\"modelica://Refrigerator.HotFood\">HotFood</a> model, you can see the effect of adding hot food to a normally loaded refrigerator instead of a near-empty one:</p>

<p style=\"text-align: center;\"><img src=\"modelica://Refrigerator/DocumentationFiles/hotFoodTemperatures.png\" style=\"width:600px\" alt=\"\" /></p>
<p>You can see that, in the normally loaded refrigerator, the fresh food temperature increases by about 2 K, which is within acceptable limits.</p>
<h4>Other Scenario</h4>
<p>Try simulating the other model in this example, <a href=\"modelica://Refrigerator.DoorOpening\">DoorOpening</a>, to explore the effects of opening and closing the refrigerator and freezer compartment doors.</p>
</div>
</div></html>", figures = {Figure(title = "Food temperature", identifier = "a6696", preferred = true, plots = {Plot(curves = {Curve(y = hotFood.temperatureSensor.T, legend = "Hot Food"), Curve(y = freshFood.temperatureSensor.T, legend = "Fresh Food"), Curve(y = frozenFood.food.T, legend = "Frozen Food")}, x = Axis(unit = "min"))}), Figure(title = "Comparment temperatures", identifier = "d852a", plots = {Plot(curves = {Curve(y = fridgeCompartment.T), Curve(y = freezerCompartment.T)}, x = Axis(unit = "min"))}), Figure(title = "Events", identifier = "bb60d", plots = {Plot(curves = {Curve(y = heatPump.switch.u2, legend = "Heat Pump")}, x = Axis(unit = "min"), y = Axis(label = "On/Off")), Plot(curves = {Curve(y = airCirculation.switch.u2, legend = "Thermostat")}, x = Axis(min = 0, max = 133.3333333333333, unit = "min"), y = Axis(label = "On/Off"))})}), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, origin = {120.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of asparagus", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {70.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "R-134a at -26.5 C", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {120.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of ice cream", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, 55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.2 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {0.0, -55.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "0.4 Kg air", fontSize = 12, fontName = "Arial"), Text(visible = true, origin = {90.0, -15.0}, fillPattern = FillPattern.Solid, extent = {{-20.0, -5.0}, {20.0, 5.0}}, textString = "2 kg of hot asparagus", fontSize = 12, fontName = "Arial")}));
  end NearEmpty;
  annotation(Documentation(info = "<html></html>"), preferredView = "info", uses(Modelica(version = "4.0.0")), __Wolfram(openClass = Refrigerator.DoorOpening), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
end Refrigerator;
